@@ -13,16 +13,16 @@ sub create_user_feature {
 
 sub read_user_feature {
 	my $self = shift;
-	$self->render( json => { data => { id => $self->stash('userid'), features => [ { id => 'mysql' }, { id => 'mails' } ] } } );
+	$self->render( json => { data => { id => $self->stash('userId'), features => [ { id => 'mysql' }, { id => 'mails' } ] } } );
 }
 
 sub update_user_feature {
 	my $self = shift;
-	$self->render( json => { data => { id => $self->stash('userid'), feature => { id => $self->stash('featureid') } } } );
+	$self->render( json => { data => { id => $self->stash('userId'), feature => { id => $self->stash('featureId') } } } );
 }
 
 sub delete_user_feature {
 	my $self = shift;
-	$self->render( json => { data => { id => $self->stash('userid'), feature => { id => $self->stash('featureid') } } } );
+	$self->render( json => { data => { id => $self->stash('userId'), feature => { id => $self->stash('featureId') } } } );
 }
 1;
